@@ -42,7 +42,7 @@ class UrlRequestResource(object):
 
     def __init__(self, resourceString):
 
-        self.properties = dict((k.lower(), v) for k, v in (x.split('=') for x in resourceString.split(';') if x))
+        self.properties = dict((k.lower(), v) for k, v in (x.split('=', 1) for x in resourceString.split(';') if x))
         self.timeout = float(self.properties.get('timeout')) if 'timeout' in self.properties else None
         self.reset()
 
